[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] xen: Last minute rename of RCU domain get/put functions:



# HG changeset patch
# User kfraser@xxxxxxxxxxxxxxxxxxxxx
# Date 1172745172 0
# Node ID a5b5279d2ba37fef5cb85adb15f83d077a5a6747
# Parent  44048a3f7caa5098368286f146cfe9a2089e9ac9
xen: Last minute rename of RCU domain get/put functions:
 find_domain_rcu_lock -> rcu_lock_domain_by_id
 domain_rcu_unlock    -> rcu_unlock_domain
Signed-off-by: Keir Fraser <keir@xxxxxxxxxxxxx>
---
 xen/common/domain.c     |    2 +-
 xen/include/xen/sched.h |   14 +++++++-------
 2 files changed, 8 insertions(+), 8 deletions(-)

diff -r 44048a3f7caa -r a5b5279d2ba3 xen/common/domain.c
--- a/xen/common/domain.c       Thu Mar 01 10:24:19 2007 +0000
+++ b/xen/common/domain.c       Thu Mar 01 10:32:52 2007 +0000
@@ -236,7 +236,7 @@ struct domain *get_domain_by_id(domid_t 
 }
 
 
-struct domain *find_domain_rcu_lock(domid_t dom)
+struct domain *rcu_lock_domain_by_id(domid_t dom)
 {
     struct domain *d;
 
diff -r 44048a3f7caa -r a5b5279d2ba3 xen/include/xen/sched.h
--- a/xen/include/xen/sched.h   Thu Mar 01 10:24:19 2007 +0000
+++ b/xen/include/xen/sched.h   Thu Mar 01 10:32:52 2007 +0000
@@ -270,16 +270,16 @@ int construct_dom0(
     char *cmdline);
 
 /*
  * find_domain_rcu_lock() is more efficient than get_domain_by_id().
  * This is the preferred function if the returned domain reference
  * is short lived,  but it cannot be used if the domain reference needs 
  * to be kept beyond the current scope (e.g., across a softirq).
- * The returned domain reference must be discarded using domain_rcu_unlock().
- */
-struct domain *find_domain_rcu_lock(domid_t dom);
-
-/* Finish a RCU critical region started by find_domain_rcu_lock(). */
-static inline void domain_rcu_unlock(struct domain *d)
+ * The returned domain reference must be discarded using rcu_unlock_domain().
+ */
+struct domain *rcu_lock_domain_by_id(domid_t dom);
+
+/* Finish a RCU critical region started by rcu_lock_domain_by_id(). */
+static inline void rcu_unlock_domain(struct domain *d)
 {
     rcu_read_unlock(&domlist_read_lock);
 }
@@ -270,16 +270,16 @@ int construct_dom0(
 
 /*
- * find_domain_rcu_lock() is more efficient than get_domain_by_id().
+ * rcu_lock_domain_by_id() is more efficient than get_domain_by_id().
  * This is the preferred function if the returned domain reference
  * is short lived,  but it cannot be used if the domain reference needs 

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.